COMMENT
-----------------------------------------------------------------------------

it2.mod	
Mechanism for T-type calcium current (low-threshold spikes)

Based on a mechanism written by Alain Destexhe (1992), as used in (e.g.): 

     	Destexhe, A., Contreras, D., Steriade, M., Sejnowski, T.J. and
     	Huguenard, J.R.  In vivo, in vitro and computational analysis of
     	dendritic calcium currents in thalamic reticular neurons.
     	Journal of Neuroscience 16: 169-185, 1996.

Slightly modified for redistribution by

	Thomas A. Cleland (tac29@cornell.edu) and Praveen Sethupathy
	Cornell University
	Summer 2003, January 2004

	In the present model, the 'ica' variable defined here is read by the 
	cadecay.mod mechanism (calcium movement), which in turn updates 'cai'.  

-----------------------------------------------------------------------------
From original descriptive text by Alain Destexhe:

Ca++ current responsible for low threshold spikes (LTS)
RETICULAR THALAMUS
Differential equations

Model of Huguenard & McCormick, J Neurophysiol 68: 1373-1383, 1992.
The kinetics is described by standard equations (NOT GHK)
using a m2h format, according to the voltage-clamp data
(whole cell patch clamp) of Huguenard & Prince, J Neurosci.
12: 3804-3817, 1992.  

    	- Kinetics adapted to fit the T-channel of reticular neuron
    	- Time constant tau_h refitted from experimental data
    	- shift parameter for screening charge

Model described in detail in:   
     	Destexhe, A., Contreras, D., Steriade, M., Sejnowski, T.J. and
     	Huguenard, J.R.  In vivo, in vitro and computational analysis of
     	dendritic calcium currents in thalamic reticular neurons.
     	Journal of Neuroscience 16: 169-185, 1996.
See also:
     	http://www.cnl.salk.edu/~alain
     	http://cns.fmed.ulaval.ca
	
Written by Alain Destexhe, Salk Institute, Sept 18, 1992

-----------------------------------------------------------------------------
ENDCOMMENT

TITLE Low threshold calcium current

INDEPENDENT {t FROM 0 TO 1 WITH 1 (ms)}

NEURON {
	SUFFIX it2
	USEION ca READ cai, cao WRITE ica		
	RANGE gcabar, m_inf, tau_m, h_inf, tau_h, shift, g
}
UNITS {
	(molar) = (1/liter)		: moles is not a recognized unit
	(mV) =	(millivolt)
	(mA) =	(milliamp)
	(mM) =	(millimolar)
	FARADAY = (faraday) (coulomb)
	R = (k-mole) (joule/degC)
}
PARAMETER {
	v		(mV)
	celsius	= 36	(degC)	: default ignored; set by NEURON (to 23 C)
:	eca	= 120	(mV)
	gcabar	= .00175 (mho/cm2)
	shift	= 2 	(mV)			: screening charge for Ca_o = 2 mM
	cai	= 2.4e-4 (mM)		: adjusted for eca=120 mV; default ignored and set by NEURON
	cao	= 2	(mM)			: default ignored and set by NEURON
}
STATE {
	m h
}
ASSIGNED {
	ica	(mA/cm2)
	carev	(mV)
	m_inf
	tau_m	(ms)
	h_inf
	tau_h	(ms)
	phi_m
	phi_h
	g
}
BREAKPOINT {
	SOLVE castate METHOD euler
	carev = (1e3) * (R*(celsius+273.15))/(2*FARADAY) * log (cao/cai)
	g = gcabar * m*m*h
	ica = g * (v-carev)
}
DERIVATIVE castate {
	evaluate_fct(v)
	m' = (m_inf - m) / tau_m
	h' = (h_inf - h) / tau_h
}
UNITSOFF
INITIAL {
	: Activation functions and kinetics were obtained from
	: Huguenard & Prince, and were at 23-25 deg.
	: Transformation to 36 deg assuming Q10 of 5 and 3 for m and h
	: (as in Coulter et al., J Physiol 414: 587, 1989)
	:
	phi_m = 5.0 ^ ((celsius-24)/10)
	phi_h = 3.0 ^ ((celsius-24)/10)
	evaluate_fct(v)
	m = m_inf
	h = h_inf
}
PROCEDURE evaluate_fct(v(mV)) { 	:Time constants were obtained from J. Huguenard
	m_inf = 1.0 / ( 1 + exp(-(v+shift+50)/7.4) )
	h_inf = 1.0 / ( 1 + exp((v+shift+78)/5.0) )
	tau_m = ( 3 + 1.0 / ( exp((v+shift+25)/10) + exp(-(v+shift+100)/15) ) ) / phi_m
	tau_h = ( 85 + 1.0 / ( exp((v+shift+46)/4) + exp(-(v+shift+405)/50) ) ) / phi_h
}
UNITSON
