COMMENT
-----------------------------------------------------------------------------

cadecay.mod	
Mechanism for perimembrane Ca concentration

Based on a mechanism written by Alain Destexhe (1995), as used in (e.g.): 

	Destexhe A, Neubig M, Ulrich D and Huguenard JR (1998) 
	Dendritic low-threshold calcium currents in thalamic relay cells.  
	J Neurosci 18:3574-3588.

Slightly modified for redistribution by

	Thomas A. Cleland (tac29@cornell.edu) and Praveen Sethupathy
	Cornell University
	Summer 2003, January 2004

	The 'cai' variable is read by the IT2.mod mechanism (calcium T-current), 
	which in turn updates the 'ica' variable.  

-----------------------------------------------------------------------------
From original descriptive text by Alain Destexhe:

Takes into account:
	- increase of cai due to calcium currents
	- extrusion of calcium with a simple first order equation

This mechanism is compatible with the calcium pump "cad" and has the 
same name and parameters; however the parameters specific to the pump
are dummy here.

Parameters:
	- depth: depth of the shell just beneath the membrane (in um)
	- cainf: equilibrium concentration of calcium (2e-4 mM)
	- taur: time constant of calcium extrusion (must be fast)
	- kt,kd: dummy parameters
	
Written by Alain Destexhe, Salk Institute, 1995

-----------------------------------------------------------------------------
ENDCOMMENT

TITLE Fast mechanism for submembranal Ca++ concentration (cai)

INDEPENDENT {t FROM 0 TO 1 WITH 1 (ms)}

NEURON {
	SUFFIX cad
	USEION ca READ ica, cai WRITE cai
	RANGE depth, kt, kd, cainf, taur, drive_channel
}
UNITS {
	(molar) = (1/liter)			: moles do not appear in units
	(mM)	= (millimolar)
	(um)	= (micron)
	(mA)	= (milliamp)
	(msM)	= (ms mM)
}
CONSTANT {
	FARADAY = 96489	(coul)		
}
PARAMETER {
	depth	= 0.1	(um)		: depth of shell
	taur	= 5	(ms)		: rate of calcium removal
	cainf	= 2e-4  (mM)
	kt	= 0	(mM/ms)	: dummy
	kd	= 0	(mM)		: dummy
}
STATE {
	cai		(mM) 
}
INITIAL {
	cai = cainf
}
ASSIGNED {
	ica		(mA/cm2)
	drive_channel	(mM/ms)
}	
BREAKPOINT {
	SOLVE state METHOD euler
}
DERIVATIVE state { 
	drive_channel =  - (10000) * ica / (2 * FARADAY * depth)
	if (drive_channel <= 0.) { drive_channel = 0. }		: cannot pump inward
	cai' = drive_channel + (cainf-cai)/taur 
}

