COMMENT
-----------------------------------------------------------------------------

ka.mod	
Mechanism for "A"-type inactivating potassium channel

Based on a mechanism written by M. Migliore (1995), as used in: 

	Migliore M, Cook E, Jaffe DB, Turner DA and Johnston D (1995)
	Computer simulations of morphologically reconstructed CA3 
	hippocampal neurons.  J Neurophysiol 73:1157-1168. 

Slightly modified for redistribution by

	Thomas A. Cleland (tac29@cornell.edu) and Praveen Sethupathy
	Cornell University
	Summer 2003, January 2004

	NB: Consider replacing this with the channel from Migliore
	et al (1996), which is CVODE-compatible.

-----------------------------------------------------------------------------
From original descriptive text by M. Migliore:

Hippocampal CA3 pyramidal neuron model from the paper 
M. Migliore, E. Cook, D.B. Jaffe, D.A. Turner and D. Johnston, Computer
simulations of morphologically reconstructed CA3 hippocampal neurons, J.
Neurophysiol. 73, 1157-1168 (1995). 

The paper shows how bursting and non bursting firing modes of CA3 
neurons can depend on the densities of the Ca-independent conductances,
that prevent the build-up of the Ca-dependent depolarizing envelope
(compare bursting and short non bursting simulations).
Calcium accumulation during long current injections results in
spike adaptation modulated by Ca-dependent conductances and KM.

Questions on how to use this model should be directed to
michele.migliore@pa.ibf.cnr.it

-----------------------------------------------------------------------------
ENDCOMMENT

TITLE Borg-Graham type generic K-A channel 

UNITS {
	(mA) = (milliamp)
	(mV) = (millivolt)
}

PARAMETER {
	v (mV)
      ek (mV)
	celsius 	(degC)
	gkabar=.01 (mho/cm2)
      vhalfn=-33.6   (mV)
      vhalfl=-83   (mV)
      a0l=0.08      (/ms)
      a0n=0.02    (/ms)
      zetan=-3    (1)
      zetal=4    (1)
      gmn=0.6   (1)
      gml=1   (1)
}


NEURON {
	SUFFIX ka
	USEION k READ ek WRITE ik
        RANGE gkabar,gka
        GLOBAL ninf,linf,taul,taun
}

STATE {
	  n
        l
}

INITIAL {
        rates(v)
        n=ninf
        l=linf
}

ASSIGNED {
	ik (mA/cm2)
	ninf
	linf      
	taul
	taun
	gka
}

BREAKPOINT {
	SOLVE states METHOD cnexp
	:gka = gkabar*n^3*l	: from Migliore original (makes pg cell freak out, though)
	gka = gkabar*n*l		: as modified by Praveen; error?  (but it works...)
	ik = gka*(v-ek)
}

FUNCTION alpn(v(mV)) {
  	alpn = exp(1.e-3*zetan*(v-vhalfn)*9.648e4/(8.315*(273.16+celsius))) 
}

FUNCTION betn(v(mV)) {
  	betn = exp(1.e-3*zetan*gmn*(v-vhalfn)*9.648e4/(8.315*(273.16+celsius))) 
}

FUNCTION alpl(v(mV)) {
  	alpl = exp(1.e-3*zetal*(v-vhalfl)*9.648e4/(8.315*(273.16+celsius))) 
}

FUNCTION betl(v(mV)) {
  	betl = exp(1.e-3*zetal*gml*(v-vhalfl)*9.648e4/(8.315*(273.16+celsius))) 
}

DERIVATIVE states { 
	rates(v)
	n' = (ninf - n)/taun
	l' = (linf - l)/taul
}

PROCEDURE rates(v (mV)) { :callable from hoc
        LOCAL a,q10
        q10=3^((celsius-30)/10)
        a = alpn(v)
        ninf = 1/(1 + a)
        taun = betn(v)/(q10*a0n*(1+a))
        a = alpl(v)
        linf = 1/(1+ a)
        taul = betl(v)/(q10*a0l*(1 + a))
}
